pub struct StartsWith { /* private fields */ }Expand description
Prefix matching filter for binary and string columns.
A row passes if its column value starts with any of the prefix values in the filter array.
Implementations